==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/GeopsyCore/src/SignalHeaderScript.h <==
/***************************************************************************
**
**  This file is part of GeopsyCore.
**
**  GeopsyCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  GeopsyCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2011-08-11
**  Copyright: 2011-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef SIGNALHEADERSCRIPT_H
#define SIGNALHEADERSCRIPT_H

#include "SubSignalPool.h"
#include "GeopsyCoreDLLExport.h"

class QJSEngine;
class SignalHeaderPrototype;

namespace GeopsyCore {

  class GEOPSYCORE_EXPORT SignalHeaderScript: public QObject
  {
    Q_OBJECT
  public:
    SignalHeaderScript(SubSignalPool * subPool);

    bool run(const QString& script);
    QJSEngine * engine() const {return _engine;}
  signals:
    void beginSignalChange(Signal * sig);
    void endSignalChange(Signal * sig);
  private:
    QJSEngine * _engine;
    SignalHeaderPrototype * _signalHeader;
  };

} // namespace GeopsyCore

#endif // SIGNALHEADERSCRIPT_H

==> geopsypack-src-3.5.2.tar.gz: geopsypack-src-3.5.2/GeopsyCore/src/SignalHeaderScript.h <==
/***************************************************************************
**
**  This file is part of GeopsyCore.
**
**  GeopsyCore is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  GeopsyCore is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2011-08-11
**  Copyright: 2011-2019
**    Marc Wathelet (ISTerre, Grenoble, France)
**
***************************************************************************/

#ifndef SIGNALHEADERSCRIPT_H
#define SIGNALHEADERSCRIPT_H

#include "SubSignalPool.h"
#include "GeopsyCoreDLLExport.h"

class QJSEngine;
class SignalHeaderPrototype;

namespace GeopsyCore {

  class GEOPSYCORE_EXPORT SignalHeaderScript: public QObject
  {
    Q_OBJECT
  public:
    SignalHeaderScript(SubSignalPool * subPool);

    bool run(const QString& script);
    QJSEngine * engine() const {return _engine;}
  signals:
    void beginSignalChange(SignalDatabase * db);
    void endSignalChange(SignalDatabase * db);
    void beginSignalChange(Signal * sig);
    void endSignalChange(Signal * sig);
  private:
    SignalDatabase * _db;
    QJSEngine * _engine;
    SignalHeaderPrototype * _signalHeader;
  };

} // namespace GeopsyCore

#endif // SIGNALHEADERSCRIPT_H
